//Lensflare Demoscene
#version 3.7
global_settings {
	assumed_gamma 1
}
#default {finish {ambient 0}}

//first include the flares-system, you just have to do this once
#include "flares.inc"


//Flare-settings:
// (all settings are optional, can be changed for each individual flare, but will not be reset to the default-values after a lensflare has been created

	//Flares_Type:
	//	 Possible types:
	// 	 1 - the classic way of doing flares, using lots of little disc-objects.
	//			  Doesn't need a high max_trace_level anymore since POV-Ray 3.7, but
	//			  you could run into a "too many nested objects"-error
	// 	 2 - the new way, using just 1 plane.  It's a lot slower, but since there's just one object added to the scene, there's no
	//			  no need for a high max_trace_level.  There is however a limit on the maximum amount of flares (which depends of the number
	//			  of 'parts' it's composed of), but the limit is a lot higher than with type 1.
	//Default: 1
	#declare Flares_Type=1;
	
	
	//Flares_Distance and Flares_Spacing:
	//	Distances between the camera and the "projection-plane" for the flares, and between 2 seperate "projection-planes"
	//	(you probably will never have to change this)
	//Default: 1e-3 (for both)
	#declare Flares_Distance=1e-3;
	#declare Flares_Spacing=1e-3;
	
	//Flares_Color and Flares_Size
	// These adjust the global color and size of the flare
	//Default: 1 (for both)
	#declare Flares_Color=1;
	#declare Flares_Size=1;
	
	//Flares_BlockSamples
	//	Defines how many sample-rays are shot to determine if the flare is visible or not
	//	(This is only relevant if a scene has been defined for blocking the flare)
	//Default: 25
	#declare Flares_BlockSamples=25;
	
	//Flares_AutoScale
	//	If true, the size of the flare will depend on the distance from the camera
	//Default: true
	#declare Flares_AutoScale=true;

//Flare-macros:
	//Setting up the camera:
		Flares_Camera_SetAngle(60) 			//set the viewing angle of the camera, default: 60
		Flares_Camera_SetRight(x*4)			//set the "right"-vector of the camera, default: x*4
		Flares_Camera_SetUp(y*3)				//set the "up"-vector of the camera, default: y*3
		Flares_Camera_SetSky(y)					//set the "sky"-vector of the camera, default: y
		Flares_Camera_Set(<0,0,0>,<0,0,1>)	//set the location and the look_at of the camera, defaults: <0,0,0> and <0,0,1>
		Flares_Camera()							//add the camera
	//setting up the scene:
		#local Scene=union {
			cylinder {0,y,.1}
			sphere {0,.2}
			pigment {rgb 1}
			translate <0,0,2>
		}
		Flares_Set_Scene(Scene)					//set the given object as flare-blocking object, default: nothing
		Flares_Unset_Scene()						//unset the flare-blocking object
	//Adding visual effects to the scene:
		//this flaresystem also allows you to add some visual effects.
		//Because it is internally just another lensflare, and since every flare is put slightly farther from the camera than the previous flare,
		//not only does the order of the effects matter, but also it matters if you put it before or after "real" lensflares!
		//So: any visual effect will affect any following lensflare, including other visual effects, but it will NOT affect previously added lensflares!
		//
		//The syntax is:
		// Flares_VisualEffect(Type,Argument)
		//
		//The following types are available:
		//	"bwnoise": black&white noise. The argument defines the intensity. Looks more like filmgrain.
		// "noise": colored noise. The argument defines the intensity. Looks more like digital noise.
		// "negative": invert all colors. The argument is ignored
		// "contrast": sets the contrast according to the argument. 0 removes all contrast, 1 doesn't change the image. Negative argument inverts the colors
		// "brightness": sets the brightness according to the argument. 0 turns everything black, 1 doesn't change the image.
		Flares_VisualEffect(
			"noise",
			.05
		)
		Flares_VisualEffect(
			"contrast",
			1.05
		)
	//Adding the flares:
		#declare Flares_Color=<.3,.1,1>/.1;
		Flares_PredefinedLensflareAt(
			"natural5",								//flare type
			<-20,12,50>,								//flare location
			2											//flare radius
		)
		#declare Flares_Color=<1,.2,.1>/.3;
		Flares_PredefinedLensflareAt(
			"sun",									//flare type, all flaretypes of Chris Colefax' lensflare-includefile will work,
														//but they're not yet updated to the new default gamma-settings
			<1,.5,2>,								//flare location
			.125										//flare radius
		)



//ignore this, it's just..
//
//..an "interesting" background!
light_source {
	<-20,12,50> rgb <.3,.1,1>/.1
	area_light x*2,y*2,5,5
	adaptive 2
	jitter
	circular orient
}
light_source {
	<1,.5,2> rgb <1,.2,.1>/.3
	area_light x*.125,y*.125,5,5
	adaptive 2
	jitter
	circular orient
}

plane {y,-.2
	pigment {rgb 1}
}
sphere {
	0,1
	pigment {granite}
	finish {diffuse 0 ambient .25}
	scale <1000,500,1000>
}
object {Scene}